import gradio as gr
from transformers import pipeline


summarizer = pipeline("summarization", model="knkarthick/bart-large-xsum-samsum")

def sentiment_analysis(text):
    result = summarizer(text, max_length=130, min_length=30, do_sample=False)

    return result[0].get('summary_text')

    
demo = gr.Interface(fn=sentiment_analysis, 
                    inputs='text',
                    outputs='text',
                    examples=[['The tower is 324 metres (1,063 ft) tall, about the same height as an 81-storey building, and the tallest structure in Paris. Its base is square, measuring 125 metres (410 ft) on each side. During its construction, the Eiffel Tower surpassed the Washington Monument to become the tallest man-made structure in the world, a title it held for 41 years until the Chrysler Building in New York City was finished in 1930. It was the first structure to reach a height of 300 metres. Due to the addition of a broadcasting aerial at the top of the tower in 1957, it is now taller than the Chrysler Building by 5.2 metres (17 ft). Excluding transmitters, the Eiffel Tower is the second tallest free-standing structure in France after the Millau Viaduct.']],
                    title = "摘要"
                    )


if __name__ == "__main__":
    demo.queue(concurrency_count=3)
    demo.launch(server_name = "0.0.0.0", server_port = 7028)
